import useEcharts from "@/Hook/useEcharts"
import { Card, Radio, Spin } from "antd"
import React, { useEffect, useRef, useState } from "react"
import style from './index.less'
import './index1.less'
import { AllSurveyTotalDataProps, getAllSurveyLineDataApi } from "@/services/gameData/allSurvey"
import { useAjax } from "@/Hook/useAjax"

interface Props {
    height: number
    queryForm: AllSurveyTotalDataProps
}
/**
 * 线图
 * @returns 
 */
const LineC: React.FC<Props> = (props) => {

    /******************/
    const { height = 0, queryForm } = props
    const { LineMonitor } = useEcharts()
    const ref = useRef(null);
    const [type, setType] = useState<string>('a')
    const [data, setData] = useState<any>({})
    /******************/

    const getAllSurveyLineData = useAjax((params) => getAllSurveyLineDataApi(params))

    useEffect(() => {
        getAllSurveyLineData.run(queryForm).then(res => {
            let a1Data: any = { legendName: '消耗' }
            let a2Data: any = { legendName: '充值' }
            let b1Data: any = { legendName: '买量充值' }
            let b2Data: any = { legendName: '自然量充值' }
            let cData: any = { legendName: '首日ROI' }
            let d1Data: any = { legendName: '新增用户' }
            res?.forEach((item: { amount: number, buyAmount: number, cost: number, dt: string, firstRoi: number, natureAmount: number, playerAccount: number }) => {
                a1Data[item.dt] = item?.cost || 0
                a2Data[item.dt] = item?.amount || 0
                b1Data[item.dt] = item?.buyAmount || 0
                b2Data[item.dt] = item?.natureAmount || 0
                cData[item.dt] = item?.firstRoi || 0
                d1Data[item.dt] = item?.playerAccount || 0
            })
            setData({
                a: [a1Data, a2Data],
                b: [b1Data, b2Data],
                c: [cData],
                d: [d1Data]
            })
        })
    }, [queryForm, type])

    return <div className={style.lineCont} ref={ref} style={{ height: `calc(100% - ${145.43 + height}px)` }}>
        <Spin wrapperClassName={'spin_100'} spinning={getAllSurveyLineData.loading}>
            <Card
                style={{ width: '100%', height: '100%', borderRadius: 8 }}
                title={<Radio.Group value={type} buttonStyle="solid" onChange={(e) => setType(e.target.value)}>
                    <Radio.Button value="a">消耗&充值</Radio.Button>
                    <Radio.Button value="b">买量充值&自然量充值</Radio.Button>
                    <Radio.Button value="c">首日ROI</Radio.Button>
                    <Radio.Button value="d">新增用户&创角人数</Radio.Button>
                </Radio.Group>}
                bodyStyle={{ padding: '0 0 24px', height: 'calc(100% - 68px)' }}
            >
                <LineMonitor style={{ width: '100%', height: '100%' }} series smooth data={data[type]} />
            </Card>
        </Spin>

    </div>
}

export default React.memo(LineC)